package Bundle::HollyKing;

$VERSION = '1.01';


# Preloaded methods go here.

1;
__END__
# Below is stub documentation for your module. You'd better edit it!

=head1 NAME

Bundle::HollyKing - Things HollyKing wants in a fresh Perl install.

=head1 SYNOPSIS

C<perl -MCPAN -e 'install Bundle::HollyKing'>

=head1 CONTENTS

App::Ack

Config::Std

Config::Tiny

Data::Dumper::Simple

DateTime

DBD::SQLite

DBI

Devel::Cover

Devel::Profiler

Devel::Size

Exception::Class

File::Slurp

Filter::Macro

Getopt::Clade

Inline

IO::InSitu

IO::Interactive

IO::Prompt

Lexical::Alias

List::Cycle

List::MoreUtils

Log::StdLog

Module::Build

Module::Starter

Module::Starter::PBP

Parse::RecDescent

Regexp::DefaultFlags

Regexp::Common

Scalar::Util

Smart::Comments

Sort::Maker

Test::Class

Test::Differences

Test::Exception

Test::Pod

Test::Pod::Coverage

Text::Autoformat

Text::CSV

Text::CSV::Simple

Text::CSV_XS

XML::Parser

YAML



=head1 AUTHOR

Brendan "HollyKing" Leber, E<lt>brendan@hollyking.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2007 by Brendan Leber

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself, either Perl version 5.8.6 or,
at your option, any later version of Perl 5 you may have available.


=cut
